tonalitytools.analyze_incomplete_tonal_function
===============================================

.. autofunction:: abjad.tools.tonalitytools.analyze_incomplete_tonal_function.analyze_incomplete_tonal_function
